@@ -1,6 +1,8 @@
 #!/usr/bin/env GoodTests.py
+'''
+    Test style attributes
+'''
 
-import re
 import subprocess
 import sys
 
